@@ -20,14 +20,12 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
-from web3 import HTTPProvider
-
 import requests
 import json
 import logging
 
 
-class BatchHTTPProvider(HTTPProvider):
+class BatchHTTPProvider(object):
     def __init__(self, endpoint_uri):
         self.endpoint_uri = endpoint_uri
         self.logger = logging.getLogger('BatchHTTPProvider')
