@@ -33,15 +33,16 @@ from thetaetl.mappers.status_mapper import ThetaStatusMapper
 
 class ThetaService(object):
     def __init__(self, theta_provider):
-        graph = BlockTimestampGraph(theta_provider)
-        self._graph_operations = GraphOperations(graph)
+        self._graph = BlockTimestampGraph(theta_provider)
+        self._graph_operations = GraphOperations(self._graph)
         self.logger = logging.getLogger('ThetaService')
 
     def get_block_range_for_date(self, date):
         start_datetime = datetime.combine(date, datetime.min.time().replace(tzinfo=timezone.utc))
         # end_datetime = datetime.combine(date, datetime.min.time().replace(tzinfo=timezone.utc))
         end_datetime = datetime.combine(date, datetime.max.time().replace(tzinfo=timezone.utc))
-        return self.get_block_range_for_timestamps(start_datetime.timestamp(), end_datetime.timestamp())
+        latest_timestamp = self._graph.get_last_point().y
+        return self.get_block_range_for_timestamps(start_datetime.timestamp(), min(latest_timestamp, end_datetime.timestamp()))
 
     def get_block_range_for_timestamps(self, start_timestamp, end_timestamp):
         start_timestamp = int(start_timestamp)
@@ -49,27 +50,29 @@ class ThetaService(object):
         if start_timestamp > end_timestamp:
             raise ValueError('start_timestamp must be greater or equal to end_timestamp')
 
-#        try:
-#           start_block_bounds = self._graph_operations.get_bounds_for_y_coordinate(start_timestamp)
-#        except OutOfBoundsError:
-#            start_block_bounds = (0, 0)
+        try:
+            start_block_bounds = self._graph_operations.get_bounds_for_y_coordinate(start_timestamp)
+        except OutOfBoundsError:
+            start_block_bounds = (0, 0)
 
-        # try:
-        #     end_block_bounds = self._graph_operations.get_bounds_for_y_coordinate(end_timestamp)
-        # except OutOfBoundsError as e:
-            #raise OutOfBoundsError('The existing blocks do not completely cover the given time range') from e
+        try:
+            end_block_bounds = self._graph_operations.get_bounds_for_y_coordinate(end_timestamp)
+        except OutOfBoundsError as e:
+            raise OutOfBoundsError('The existing blocks do not completely cover the given time range') from e
 
-        # if start_block_bounds == end_block_bounds and start_block_bounds[0] != start_block_bounds[1]:
-        #     self.logger.info("end_block_bounds[0] %d,  end_block_bounds[1] : %d, start_block_bounds[0] %d, start_block_bounds[1] %d \n", 
-        #         end_block_bounds[0], end_block_bounds[1], start_block_bounds[0], start_block_bounds[1])
-            # raise ValueError('The given timestamp range does not cover any blocks')
+        if start_block_bounds == end_block_bounds and start_block_bounds[0] != start_block_bounds[1]:
+            self.logger.info("end_block_bounds[0] %d,  end_block_bounds[1] : %d, start_block_bounds[0] %d, start_block_bounds[1] %d \n", 
+                end_block_bounds[0], end_block_bounds[1], start_block_bounds[0], start_block_bounds[1])
+            raise ValueError('The given timestamp range does not cover any blocks')
 
-        start_block = 1#start_block_bounds[1]
-        end_block = 200#end_block_bounds[0]
+        start_block = start_block_bounds[1]
+        end_block = end_block_bounds[0]
 
-        # The genesis block has timestamp 0 but we include it with the 1st block.
-        # if start_block == 1:
-        #     start_block = 0
+        # Theta do not support index 0
+        if start_block == 0:
+            start_block = 1
+        if end_block == 0:
+            end_block = 1
 
         return start_block, end_block
 
